@@ -14,7 +14,7 @@ class Stack:
 
   def peek(self):
     assert self._data.size() > 0
-    return self._data.rbegin()()
+    return self._data.rbegin().get()
 
   def pop(self):
     assert self._data.size() > 0
